Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2204)

Unified Diff: chrome/browser/search_engines/template_url_model.cc

Issue 6804032: Add TLS-SRP (RFC 5054) support Base URL: http://git.chromium.org/git/chromium.git@trunk
Patch Set: use system srp and mpi libs, not local copies Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/search_engines/template_url_model.cc
diff --git a/chrome/browser/search_engines/template_url_model.cc b/chrome/browser/search_engines/template_url_model.cc
index 9a7a19316703c8bb5ab78b98cf41e07b6eb7c0f9..8a385611217dbd5434cec5967ed449e595a52a07 100644
--- a/chrome/browser/search_engines/template_url_model.cc
+++ b/chrome/browser/search_engines/template_url_model.cc
@@ -158,13 +158,16 @@ string16 TemplateURLModel::CleanUserInputKeyword(const string16& keyword) {
if (url_parse::ExtractScheme(UTF16ToUTF8(keyword).c_str(),
static_cast<int>(keyword.length()),
&scheme_component)) {
// If the scheme isn't "http" or "https", bail. The user isn't trying to
// type a web address, but rather an FTP, file:, or other scheme URL, or a
// search query with some sort of initial operator (e.g. "site:").
if (result.compare(0, scheme_component.end(),
ASCIIToUTF16(chrome::kHttpScheme)) &&
result.compare(0, scheme_component.end(),
- ASCIIToUTF16(chrome::kHttpsScheme)))
+ ASCIIToUTF16(chrome::kHttpsScheme)) &&
+ result.compare(0, scheme_component.end(),
+ ASCIIToUTF16(chrome::kHttpsvScheme)))
return string16();
// Include trailing ':'.
@@ -158,13 +158,16 @@ string16 TemplateURLModel::CleanUserInputKeyword(const string16& keyword) {
static_cast<int>(keyword.length()),
&scheme_component)) {
- // If the scheme isn't "http" or "https", bail. The user isn't trying to
- // type a web address, but rather an FTP, file:, or other scheme URL, or a
- // search query with some sort of initial operator (e.g. "site:").
+ // If the scheme isn't "http", "https", or "httpsv", bail. The user isn't
+ // trying to type a web address, but rather an FTP, file:, or other scheme
+ // URL, or a search query with some sort of initial operator
+ // (e.g. "site:").
if (result.compare(0, scheme_component.end(),
ASCIIToUTF16(chrome::kHttpScheme)) &&

Powered by Google App Engine
This is Rietveld 408576698